/* -*- Mode: C; c-basic-offset: 4 -*-
 * pygtk- Python bindings for the GTK toolkit.
 *
 *   scwmodule.c: wrapper for scw GObject library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif
#include <Python.h>

#include <pygobject.h>
#include <scwview.h>

void pyscw_register_classes (PyObject *d);
void pyscw_add_constants(PyObject *module, const gchar *strip_prefix);

extern PyMethodDef pyscw_functions[];

DL_EXPORT(void)
initscw (void)
{
    PyObject *m, *d;

    m = Py_InitModule("scw", pyscw_functions);
    d = PyModule_GetDict(m);

    init_pygobject();

    PyModule_AddObject(m, "TYPE_TIMESTAMP",   pyg_type_wrapper_new(SCW_TYPE_TIMESTAMP));
    PyModule_AddObject(m, "TYPE_PRESENCE",    pyg_type_wrapper_new(SCW_TYPE_PRESENCE));
    PyModule_AddObject(m, "TYPE_ROW_COLOR",   pyg_type_wrapper_new(SCW_TYPE_ROW_COLOR));

    PyModule_AddObject(m, "INTERACTION_SELECT",    PyInt_FromLong(SCW_INTERACTION_SELECT));
    PyModule_AddObject(m, "INTERACTION_PAN",       PyInt_FromLong(SCW_INTERACTION_PAN));
    PyModule_AddObject(m, "INTERACTION_SMART_PAN", PyInt_FromLong(SCW_INTERACTION_SMART_PAN));

    pyscw_register_classes(d);
}


/* These should be exported symbols from pygtk's _gtk.so, but a schoolboy error
 * means that they're not.  Adding temporarily here until fixed upstream
 */
PyObject *
pygtk_tree_path_to_pyobject(GtkTreePath *path)
{
    gint len, i, *indices;
    PyObject *ret;

    len = gtk_tree_path_get_depth(path);
    indices = gtk_tree_path_get_indices(path);
    ret = PyTuple_New(len);
    for (i = 0; i < len; i++)
    PyTuple_SetItem(ret, i, PyInt_FromLong(indices[i]));
    return ret;
}

GtkTreePath *
pygtk_tree_path_from_pyobject(PyObject *object)
{
    if (PyString_Check(object)) {
    GtkTreePath *path;

    path = gtk_tree_path_new_from_string(PyString_AsString(object));
    return path;
    } else if (PyInt_Check(object)) {
    GtkTreePath *path;

    path = gtk_tree_path_new();
    gtk_tree_path_append_index(path, PyInt_AsLong(object));
    return path;
    } else if (PyTuple_Check(object)) {
    GtkTreePath *path;
    guint len, i;

    len = PyTuple_Size(object);
    if (len < 1)
        return NULL;
    path = gtk_tree_path_new();
    for (i = 0; i < len; i++) {
        PyObject *item = PyTuple_GetItem(object, i);
        gint index = PyInt_AsLong(item);
        if (PyErr_Occurred()) {
        gtk_tree_path_free(path);
        PyErr_Clear();
        return NULL;
        }
        gtk_tree_path_append_index(path, index);
    }
    return path;
    }
    return NULL;
}

